@@ -6,17 +6,17 @@ use utf8;
 
 print "\n------------------------------------------------\n";
 
-print "#xs small strings\n";
+print "small strings\n";
 timethis(1000000, 'distance("four","fuoru");'); 
 
 print "------------------------------------------------\n";
 
-print "#xs medium strings\n";
+print "medium strings\n";
 timethis(1000000, 'distance("four" x 1000,"fuoru" x 1000);'); 
 
 print "------------------------------------------------\n";
 
-print "#xs large strings\n";
+print "large strings\n";
 timethis(1000000, 'distance("four" x 100000,"fuoru" x 100000);'); 
 
 print "------------------------------------------------\n";
